@@ -40,6 +40,7 @@ struct vaul_design_unit;
 struct vaul_error_printer : vaul_printer {
 
     vaul_error_printer ();
+    virtual ~vaul_error_printer () {};
 
     void info (const char *fmt, ...);
     void error(const char *fmt, ...);
@@ -193,7 +194,7 @@ struct vaul_parser_options {
     debug = val;
   }
 
-  bool set_allow_invisible_default_bindings_from_work (bool val)
+  void set_allow_invisible_default_bindings_from_work (bool val)
   {
     allow_invisible_default_bindings_from_work = val;
   }
