@@ -2,15 +2,21 @@
 #if HAVE_ALLOCA_H
 #include <alloca.h>
 #endif
+#if HAVE_MALLOC_H
+#include <malloc.h>
+#endif
 #include <string.h>
 #include <fstream>
 #include <sstream>
 #include <map>
 #include <stdlib.h>
-#include <regex.h>
 #include <stdio.h>
 #include <sys/types.h>
 
+extern "C" {
+#include <regex.h>
+}
+
 #include <freehdl/kernel-acl.hh>
 #include <freehdl/kernel-flags.hh>
 #include <freehdl/kernel-kernel-class.hh>
@@ -43,7 +49,7 @@ fstream file;
 string timescale_unit = "ns";
 int timescale = 1;
 int coef_str_length = 7;
-bool quiet = true; 
+bool quiet = false; 
 
 buffer_stream dump_buffer;
 buffer_stream file_buffer;
@@ -276,10 +282,14 @@ time_conversion(const lint &tval, const int &coef_str_length )
   const int diff =  str_len - coef_str_length;
   // if this difference is positiv(i.e: time value is greater 
   // than coefficient time, which actually presents timescale
-  if (diff >= 0){
+  if (diff > 0) {
     strcpy(stock_time,(cursor+1));
     stock_time[diff] = '\0';
-    
+  } else if(diff == 0) {
+    // the case occurs when the time grid (timescale + timeunit) is too
+    // small to represent the change of the signal
+    stock_time[0] = '0';
+    stock_time[1] = '\0';
   } else if(diff < 0) {
     stock_time[0] = '0';
     stock_time[1] = '\0';
@@ -458,7 +468,7 @@ get_size_range(fhdl_ostream_t &outp, list<signal_dump*>::iterator it, ostringstr
 
       //diplays a warning on the screen indicating the inversion range of this array.
       //This will be done if quiet si true:  
-      if (quiet)
+      if (!quiet)
 	outp <<"warning: Direction of signal " << (*it)->instance_name.c_str() 
 	     <<"["<<ainfo->left_bound<< " to " << ainfo->right_bound <<"]" 
 	     << "  will be converted to "<<"["<<ainfo->right_bound
@@ -527,7 +537,7 @@ get_size_range(fhdl_ostream_t &outp, list<signal_dump*>::iterator it, ostringstr
     range <<"";
   }
 
-  return range, size;
+  return size;
 }
 
 
@@ -695,7 +705,7 @@ void write_header(fhdl_ostream_t &outp, char* fileName)
       path_vec.pop_back ();
 
       // get first element that is not equal
-      const int diff = find_different_element (path_vec, current_path);
+      const unsigned int diff = find_different_element (path_vec, current_path);
       
       while (diff < current_path.size ())
 	{
@@ -776,17 +786,17 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
   //file_buffer initialisation
   file_buffer.clean();
   // print help on the screen
-  print_help(outp);
+  if (!quiet) print_help(outp);
 
   // Print the current simulation time
-  print_sim_time(outp);
+  if (!quiet) print_sim_time(outp);
  
 
   while (true) {
 
     if (!inp.eof()) {
       // Output prompt
-      outp << "> "; outp.flush();
+      if (!quiet) outp << "> "; outp.flush();
       // Read next command to excute
       inp >> cmd;
 
@@ -794,7 +804,7 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
       cmd = "q";
  
     // Quit simulation
-     if (cmd == "q" || cmd == "quit"){
+    if (cmd == "q" || cmd == "quit"){
 
        //Writing the file buffer in the waveform file
        write_in_file(file_buffer);
@@ -816,7 +826,7 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
       // Execute next simulation cycle
       kernel.next_cycle();
       // Print simulation time
-      print_sim_time(outp);
+      if (!quiet) print_sim_time(outp);
 
     // Cycle
     } else if (cmd == "c" || cmd == "cycle") {
@@ -828,35 +838,39 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 	write_header(outp, fileName);
 	header_written = false;
       }
-      outp << "Number of cycles to execute? "; outp.flush();
+      if (!quiet) outp << "Number of cycles to execute? "; outp.flush();
       int cycles;
       inp >> cycles;
-      outp << "Executing " << cycles << " simulation cycles.\n";
+      if (!quiet) outp << "Executing " << cycles << " simulation cycles.\n";
       while (cycles--) {
 	// Execute next simulation cycle
 	kernel.next_cycle();
       }
       // Print simulation time
-      print_sim_time(outp);
-      outp << "\n";
-      STATISTICS(outp << kernel.executed_processes_counter - counter_start 
-		 << " processes were executed.\n";);
-      STATISTICS(outp << kernel.created_transactions_counter -  transactions_counter
-		 << " transaction were created.\n";);
+      if (!quiet) {
+	print_sim_time(outp);
+	outp << "\n";
+	STATISTICS(outp << kernel.executed_processes_counter - counter_start 
+		   << " processes were executed.\n";);
+	STATISTICS(outp << kernel.created_transactions_counter -  transactions_counter
+		   << " transaction were created.\n";);
+      }
 
     // Run
     } else if (cmd == "r" || cmd == "run") {
-      outp << "Run simulation for which time span? "; outp.flush();
+      if (!quiet)
+	outp << "Run simulation for which time span? "; outp.flush();
       int val, i;
       inp >> val;
       string time_unit;
       inp >> time_unit;
-      outp << "\n";
+      if (!quiet)
+	outp << "\n";
 
       for (i=0; i < L3std_Q8standard_I4time::unit_count; i++)
 	if (!strcmp(time_unit.c_str(), L3std_Q8standard_I4time::units[i])) break;
       if (i == L3std_Q8standard_I4time::unit_count) {
-	outp << "Unknown time unit " << time_unit << "\n";
+	kernel_error_stream << "Unknown time unit " << time_unit << "\n";
 	continue;
       }
        //call initial_values function
@@ -870,7 +884,9 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 
       lint time_value = kernel.get_sim_time();
       time_value = time_value + L3std_Q8standard_I4time::scale[i] * (lint)val;
-      outp << "Simulating model to time " << val << " " << time_unit << "\n";
+      if (!quiet) {
+	outp << "Simulating model to time " << val << " " << time_unit << "\n";
+      }
       
 #ifdef PERFMON_STATISTICS
       start_pcounter(main_argc, main_argv);
@@ -884,12 +900,14 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 #endif
 
       // Print simulation time
-      print_sim_time(outp);
-      outp << "\n";
-      STATISTICS(outp << kernel.executed_processes_counter - counter_start << 
-		 " processes were executed.\n";);
-      STATISTICS(outp << kernel.created_transactions_counter - transactions_counter 
-		 << " transaction were created.\n";);
+      if (!quiet) {
+	print_sim_time(outp);
+	outp << "\n";
+	STATISTICS(outp << kernel.executed_processes_counter - counter_start << 
+		   " processes were executed.\n";);
+	STATISTICS(outp << kernel.created_transactions_counter - transactions_counter 
+		   << " transaction were created.\n";);
+      }
       
     // Print all signals
     } else if (cmd == "s" || cmd == "show") {
@@ -1021,7 +1039,7 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 	  sub_cmd >> test_fileName;
 	  // valid file name?
 	  if (!char_verifier(test_fileName))
-	    outp << "'" << test_fileName << "' is not a valid file name! Output file name is set to 'wave.dmp'!\n";
+	    kernel_error_stream << "'" << test_fileName << "' is not a valid file name! Output file name is set to 'wave.dmp'!\n";
 	  else
 	    strcpy(fileName, test_fileName);
 
@@ -1032,7 +1050,7 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 	  time_unit_conversion(timescale_unit);
 	} else if (cmd == "-q"){ 
 	  // assign quiet to false dont allow a display on screen of comments
-	  quiet = false;
+	  quiet = true;
 	} else if (cmd == "-cfg") {
 	  // name of the file containing translation table
 	  char fileTranslation[1000];
@@ -1040,7 +1058,7 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 	  sub_cmd >> fileTranslation;
 	  // valid file name?
 	  if (!char_verifier(fileTranslation))
-	    outp << "'" << fileTranslation << "' is not a valid file name!\n";
+	    kernel_error_stream << "'" << fileTranslation << "' is not a valid file name!\n";
 	  else
 	    // call the reading file to get user defined translation table
 	    mapping_translation_table = get_map_list( fileTranslation);
@@ -1084,7 +1102,7 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 	{
 	  db_base::db_key_entry_pair &entry = kernel_db.find (*iter);
 	  outp << entry.first->get_name () << "(" << (int)((long)(*iter).value) << ") :"; 
-	  for (int i = 0; i < entry.second.size (); i++)
+	  for (unsigned int i = 0; i < entry.second.size (); i++)
 	    if (entry.second [i] != NULL)
 	      outp << " " << entry.second [i]->get_name ();
 
@@ -1094,17 +1112,17 @@ void scc(fhdl_istream_t &inp, fhdl_ostream_t &outp) {
 
 #ifdef EVENT_PROFILE
      else if (cmd == "p" || cmd == "profile") {
-      outp << "Print into file: "; outp.flush();
+      if (!quiet) outp << "Print into file: "; outp.flush();
       char filename[80];
       inp >> filename;
-      outp << "\n";
+      if (!quiet) outp << "\n";
       kernel.event_report(filename);
     }
 #endif
      else {
     // Check for valid command
-       outp << "unknown command '" << cmd << "'. Type h for help.\n";
-       outp.flush();
+       kernel_error_stream << "Unknown command '" << cmd << "'. Type h for help.\n";
+       kernel_error_stream.flush();
      }
   }
 }
@@ -1144,7 +1162,7 @@ kernel_main (int argc, char *argv[], handle_info *hinfo) {
       i++;
       string cmds = string (i < argc? argv[i] : "");
       string cmd;
-      for (int s = 0; s < cmds.size (); s++)
+      for (unsigned int s = 0; s < cmds.size (); s++)
 	{
 	  // Search for ';' or end of string
 	  if (cmds [s] == ';')
@@ -1238,6 +1256,8 @@ kernel_main (int argc, char *argv[], handle_info *hinfo) {
       kernel_error_stream << "error: system does not have socket support!\n";
 #endif
 
+    } else if (!strcmp(argv[i], "-q")) {
+      quiet = true;
     } else {
       kernel_error_stream << "Unkown command line argument '" << argv[i] << "'. Simulation run aborted!\n";
       exit(1);
