@@ -2,6 +2,9 @@
 #if HAVE_ALLOCA_H
 #include <alloca.h>
 #endif
+#if HAVE_MALLOC_H
+#include <malloc.h>
+#endif
 #include <stdlib.h>
 #include <freehdl/std-vhdl-types.hh>
 #include <freehdl/kernel-sig-info.hh>
