@@ -223,12 +223,21 @@ static string
 make_absolute (string fn)
 {
   if (fn.size() == 0 || fn[0] == '/')
-    return fn;
+    {
+#ifdef _WIN32
+      for (int i = 0; i < fn.size(); i++) if (fn[i] == '\\') fn[i] ='/';
+#endif
+      return fn;
+    }
   else
     {
       const int buffer_size = 4096;
       char *buffer = (char*)malloc (sizeof (char) * buffer_size);
       assert (getcwd (buffer, buffer_size) != NULL);
+#ifdef _WIN32
+      for (int i = 0; buffer[i] && i < buffer_size; i++)
+	if (buffer[i] == '\\') buffer[i] ='/';
+#endif
       fn = string (buffer) + "/" + fn;
       free (buffer);
       return fn;
@@ -1943,7 +1952,7 @@ m_emit_hdr (pIIR_ScalarSubtype sst, string &str, RegionStack &rstack, int l)
 	  str +=
 	    "   " +
 	    qid(decl, rstack, INFO) + "():physical_info_base(" + 
-	    to_string(range.left) + "LL,"+ to_string(right) + "LL," + 
+	    to_string(range.left) + "LL,"+ to_string(range.right) + "LL," + 
 	    to_string(min(range.left,range.right)) + "LL," + to_string(max(range.left, range.right)) +
 	    "LL," + base_info_str + "->units," + base_info_str + "->scale," +
 	    base_info_str + "->unit_count) {};\n";
