@@ -1,6 +1,9 @@
 #if HAVE_ALLOCA_H
 #include <alloca.h>
 #endif
+#if HAVE_MALLOC_H
+#include <malloc.h>
+#endif
 #include <math.h>
 
 #include "v2cc-util.h"
@@ -172,7 +175,7 @@ get_library_and_unit_name(pIIR_Declaration decl)
   string lname = get_long_name(decl);
   // Extract library and unit name from path
   string str;
-  int i = 1;
+  unsigned int i = 1;
   while (i < lname.length() && lname[i] != ':') str += tolower(lname[i++]);
   result.push_back(str);
   i++; 
@@ -565,7 +568,7 @@ cdfg_emit_folded_value(StaticDataType &data, string &str, RegionStack &rstack, p
     // Replace 'e' ein the floating point number by 'l' in order to
     // match the definition of doubles in lisp.
     string result = to_string(data.double_value());
-    for (int i = 0; i < result.length(); i++)
+    for (unsigned int i = 0; i < result.length(); i++)
       if (result[i] == 'e' ||
 	  result[i] == 'E')
 	result[i] = 'l';
@@ -1013,8 +1016,8 @@ get_escaped_string (const string str, const string escape_chars)
   string id, result;
 
   // Convert declarator string to lower and add result to id 
-  for (int i = 0; i < str.size(); i++) {
-    for (int j = 0; j < escape_chars.length(); j++)
+  for (unsigned int i = 0; i < str.size(); i++) {
+    for (unsigned int j = 0; j < escape_chars.length(); j++)
       if (escape_chars[j] == str[i]) {
 	result += string("\\");
 	break;
