@@ -234,7 +234,7 @@ inline string
 convert_string(const string &str, int (*f)(int)) 
 {
   string result = str;
-  for (int i = 0; i < result.length(); i++)
+  for (unsigned int i = 0; i < result.length(); i++)
     result[i] = (*f)(result[i]);
 
   return result;
