@@ -752,7 +752,7 @@ emit (vaul_pool *pool, char *file, string &str, string &cdfg_str, string &main_c
   // overide any previous ones... First, generate an id string for
   // each library unit.
   vector<string> ids (du_vec.size ());
-  for (int i = 0; i < du_vec.size (); i++)
+  for (unsigned int i = 0; i < du_vec.size (); i++)
     {
       RegionStack rstack;
       rstack.push(root_node);
@@ -775,7 +775,7 @@ emit (vaul_pool *pool, char *file, string &str, string &cdfg_str, string &main_c
   
 
   if (success && !dry_run)
-    for (int i = 0; i < du_vec.size (); i++)
+    for (unsigned int i = 0; i < du_vec.size (); i++)
       {
 	vaul_design_unit *du = du_vec [i];
 
@@ -833,7 +833,7 @@ emit (vaul_pool *pool, char *file, string &str, string &cdfg_str, string &main_c
 	  exit(1);
       }
 
-  for (int i = 0; i < du_vec.size (); i++)
+  for (unsigned int i = 0; i < du_vec.size (); i++)
     du_vec [i]->release();
   
   // Allow garbage collector to destroy root node
