@@ -282,7 +282,7 @@ psr::pop_scope (pIIR_DeclarativeRegion s)
 	      || pIIR_ConstantDeclaration(d)->initial_value != NULL)
 	    continue;
 
-	  pIIR_Declaration d2;
+	  pIIR_Declaration d2 = NULL;
 	  for (pIIR_DeclarationList dl2 = s->declarations; dl2;
 	       dl2 = dl2->rest)
 	    {
