@@ -957,6 +957,7 @@ mode_name (IR_Mode m)
     case IR_LINKAGE_MODE:
       return "linkage";
     }
+  return NULL;
 }
 
 // Check whether the expression E can be read.
@@ -2061,7 +2062,7 @@ psr::build_Aggregate (pVAUL_AmbgAggregate aggr, pIIR_Type t)
 	  for (; cl; cl = cl->rest)
 	    {
 	      pIIR_Choice c = cl->first;
-	      pIIR_IndexedAssociation ia;
+	      pIIR_IndexedAssociation ia = NULL;
 
 	      if (c->is(IR_CHOICE_BY_EXPRESSION))
 		{
@@ -2103,6 +2104,7 @@ psr::build_Aggregate (pVAUL_AmbgAggregate aggr, pIIR_Type t)
     }
   else
     error ("%n is not a composite type", t);
+  return NULL;
 }
 
 static bool
@@ -2833,6 +2835,7 @@ psr::range_from_assoc (pVAUL_GenAssocElem assoc)
     }
   else
     info ("XXX - no `%s' ranges", assoc->kind_name());
+  return NULL;
 }
 
 pIIR_Type
